@@ -4,7 +4,7 @@
 package Lingua::Interset::FeatureStructure;
 use strict;
 use warnings;
-our $VERSION = '2.047';
+our $VERSION = '2.048';
 
 use utf8;
 use open ':utf8';
@@ -1841,6 +1841,7 @@ sub matches
 sub as_string
 {
     my $self = shift;
+    my @features = $self->get_nonempty_features();
     my @assignments = map
     {
         my $f = $_;
@@ -1855,7 +1856,7 @@ sub as_string
         }
         "$f=$v";
     }
-    (grep{$self->{$_} ne ''}(known_features()));
+    (@features);
     return "[".join(', ', @assignments)."]";
 }
 
@@ -2308,7 +2309,7 @@ Lingua::Interset::FeatureStructure - Definition of morphosyntactic features and
 
 =head1 VERSION
 
-version 2.047
+version 2.048
 
 =head1 SYNOPSIS
 
