@@ -4,7 +4,7 @@
 package Lingua::Interset::Tagset::LA::Itconll;
 use strict;
 use warnings;
-our $VERSION = '2.047';
+our $VERSION = '2.048';
 
 use utf8;
 use open ':utf8';
@@ -23,7 +23,9 @@ extends 'Lingua::Interset::Tagset::Conll';
 #------------------------------------------------------------------------------
 sub get_tagset_id
 {
-    return 'la::itconll';
+    # The la::it and la::itconll drivers have mutually compatible values of the
+    # other feature, thus they should use the same value of the tagset feature.
+    return 'la::it';
 }
 
 
@@ -2285,7 +2287,7 @@ Lingua::Interset::Tagset::LA::Itconll - Driver for the tagset of the Index Thomi
 
 =head1 VERSION
 
-version 2.047
+version 2.048
 
 =head1 SYNOPSIS
 
